# Generated by Django 4.2.23 on 2025-09-11 23:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0002_delete_pypi'),
    ]

    operations = [
        migrations.CreateModel(
            name='ASNDetail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('project', models.CharField(default='bomiot', max_length=255, verbose_name='Project Name')),
                ('is_delete', models.BooleanField(default=False, verbose_name='Delete Label')),
                ('created_time', models.DateTimeField(auto_now_add=True, verbose_name='Created Time')),
                ('updated_time', models.DateTimeField(auto_now=True, null=True, verbose_name='Updated Time')),
                ('data', models.JSONField()),
            ],
            options={
                'verbose_name': 'bomiot ASN Detail',
                'verbose_name_plural': 'bomiot ASN Detail',
                'db_table': 'bomiot_asn_detail',
                'ordering': ['-id'],
            },
        ),
        migrations.CreateModel(
            name='DNDetail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('project', models.CharField(default='bomiot', max_length=255, verbose_name='Project Name')),
                ('is_delete', models.BooleanField(default=False, verbose_name='Delete Label')),
                ('created_time', models.DateTimeField(auto_now_add=True, verbose_name='Created Time')),
                ('updated_time', models.DateTimeField(auto_now=True, null=True, verbose_name='Updated Time')),
                ('data', models.JSONField()),
            ],
            options={
                'verbose_name': 'bomiot DN Detail',
                'verbose_name_plural': 'bomiot DN Detail',
                'db_table': 'bomiot_dn_detail',
                'ordering': ['-id'],
            },
        ),
        migrations.CreateModel(
            name='StockBin',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('project', models.CharField(default='bomiot', max_length=255, verbose_name='Project Name')),
                ('is_delete', models.BooleanField(default=False, verbose_name='Delete Label')),
                ('created_time', models.DateTimeField(auto_now_add=True, verbose_name='Created Time')),
                ('updated_time', models.DateTimeField(auto_now=True, null=True, verbose_name='Updated Time')),
                ('data', models.JSONField()),
            ],
            options={
                'verbose_name': 'bomiot Stock Bin',
                'verbose_name_plural': 'bomiot Stock Bin',
                'db_table': 'bomiot_stock_bin',
                'ordering': ['-id'],
            },
        ),
        migrations.DeleteModel(
            name='API',
        ),
        migrations.AddField(
            model_name='asn',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='bar',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='bin',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='capital',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='customer',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='dn',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='driver',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='example',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='fee',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='goods',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='purchase',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='stock',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='supplier',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='team',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
    ]



from os.path import join, exists
from os import makedirs, getcwd
import os
import sys
import shutil
from pathlib import Path
from .init import create_file
import importlib.metadata
from configparser import ConfigParser
from .copyfile import copy_files


def project(folder: str):
    """
    project workspace
    :param folder:
    :return:
    """
    if len(sys.argv) < 3:
        print('Please enter your project name')
    else:
        project_path = join(getcwd(), sys.argv[2])
        if exists(project_path):
            print('Project directory already exists')
        else:
            if sys.argv[2] in [dist.metadata['Name'] for dist in importlib.metadata.distributions()]:
                print('Project directory already exists')
            else:
                makedirs(project_path)
                current_path = Path(__file__).resolve()
                file_path = join(current_path.parent, 'file')

                shutil.copy2(join(file_path, '__version__.py'), project_path)

                with open(join(project_path, '__init__.py'), "w") as f:
                    f.write("def version():\n")
                    f.write(f"    from {sys.argv[2]} import __version__\n")
                    f.write("    return __version__.version()\n")
                f.close()

                shutil.copy2(join(file_path, 'bomiotconf.ini'), project_path)
                shutil.copy2(join(file_path, 'receiver.py'), project_path)
                shutil.copy2(join(file_path, 'example.py'), project_path)
                shutil.copy2(join(file_path, 'api.py'), project_path)

                create_file(str(sys.argv[2]))

                setup_ini_path = join(getcwd(), 'setup.ini')
                if not exists(setup_ini_path):
                    shutil.copy2(join(file_path, 'setup.ini'), setup_ini_path)
                setup_config = ConfigParser()
                setup_config.read(setup_ini_path, encoding='utf-8')
                project_name = setup_config.get('project', 'name', fallback='bomiot')
                if project_name.lower() == 'bomiot':
                    setup_config.set('project', 'name', folder)
                with open(setup_ini_path, "wt", encoding='utf-8') as f:
                    setup_config.write(f)

                copy_files(join(join(current_path.parent.parent, 'server'), 'media'), join(project_path, 'media'))
                copy_files(join(join(current_path.parent.parent, 'server'), 'language'), join(project_path, 'language'))
                copy_files(join(current_path.parent.parent, 'templates'), join(project_path, 'templates'))
                
                print(f'Initialized project workspace {sys.argv[2]}')